USB: dwc3-msm: Disable pipe clock requirement for HS/FS only mode

USB3 core expects pipe clock input for USB connection establishment
and functionality working. In case of maximum speed of USB3 core set
to HS/FS mode, it is required to disable pipe clock requirement and
instead use UTMI clock from HS PHY as clock input. Hence disable
this pipe clock requirement for the case, where maximum speed is set
to FS as well.

Change-Id: Ife9d6a16e1607b40c71eb1897947bf4645ac9561
Signed-off-by: Vijayavardhan Vennapusa <vvreddy@codeaurora.org>
diff --git a/drivers/usb/dwc3/dwc3-msm.c b/drivers/usb/dwc3/dwc3-msm.c
index 81f3384..6b32e9e 100644
--- a/drivers/usb/dwc3/dwc3-msm.c
+++ b/drivers/usb/dwc3/dwc3-msm.c
@@ -1768,9 +1768,10 @@
 
 		/*
 		 * Below sequence is used when controller is working without
 		 * having ssphy and only USB high speed is supported.
 		 */
-		if (dwc->maximum_speed == USB_SPEED_HIGH) {
+		if (dwc->maximum_speed == USB_SPEED_HIGH ||
+					dwc->maximum_speed == USB_SPEED_FULL) {
 			dwc3_msm_write_reg(mdwc->base, QSCRATCH_GENERAL_CFG,
 				dwc3_msm_read_reg(mdwc->base,
 				QSCRATCH_GENERAL_CFG)
@@ -1768,9 +1768,10 @@
 		/*
 		 * Below sequence is used when controller is working without
-		 * having ssphy and only USB high speed is supported.
+		 * having ssphy and only USB high/full speed is supported.
 		 */